import java.io.*;
import java.util.*;
import javax.mail.*;

public class MailPeek {
    private static String CFG = null; 
    public static void main(String[] args) {
        CFG = MailPeek.class.getName() + ".properties";
        if (args.length < 4) {
            System.out.println("");
            System.out.println("USAGE: " + MailPeek.class.getName() + " <server> <username> <password> <protocol>");
            System.out.println("");
            System.out.println("IMPORTANT:");
            System.out.println("----------");
            System.out.println("Protocol is one of imap/imaps/pop3/pop3s");
            System.out.println("If an argument (e.g. password) has a space or a special character, enclose it in single quotes (').");
            System.out.println("");
            System.exit(1);
        }
        Properties props = new Properties(System.getProperties());
        InputStream pis = MailPeek.class.getClassLoader().getResourceAsStream(CFG);
        if (pis == null)
        {
            System.err.println("ERROR: Cannot find properties file " + CFG);
            System.exit(1);
        }

        try {
            props.load(pis);
            System.out.println(props);
            String server = trim(args[0]);
            String username = trim(args[1]);
            String password = trim(args[2]);
            String proto = trim(args[3]).toLowerCase();
            System.out.println("SERVER: " + server + " USERNAME: " + username + " PASSWORD: " + password + " PROTOCOL: " + proto);
            if (!(proto.equals("imap") || proto.equals("imaps") || proto.equals("pop3") || proto.equals("pop3s")))
            {
                System.out.println("ERROR invalid protocol: " + proto);
                System.exit(1);
            }
            props.setProperty("mail.store.protocol", proto);
            Session session = Session.getInstance(props, null);
            Store store = session.getStore();
            store.connect(server, username, password);
            Folder inbox = store.getFolder("INBOX");
            inbox.open(Folder.READ_WRITE);
            Message msg = inbox.getMessage(inbox.getMessageCount());
            Address[] in = msg.getFrom();
            System.out.println("\n---------------- MAIL INFO ---------------------\n");
            for (Address address : in) {
                System.out.println("FROM:   " + address.toString());
            }
            System.out.println("SENT:    " + msg.getSentDate());
            System.out.println("SUBJECT: " + msg.getSubject());
            System.out.println("");
            System.out.println("SUCCESS!");
            System.out.println("");
            System.exit(0);
        } catch (Exception mex) {
            mex.printStackTrace();
            System.out.println("");
            System.out.println("FAILURE!");
            System.out.println("");
        }
        System.exit(1);
    }
    private static String trim(String s)
    {
        if (s == null) { return ""; }
        return s.trim();
    }
}
